Python FedEx SOAP API Module
============================

:Author: Greg Taylor
:License: BSD

What is it?
-----------

A light wrapper around FedEx's Webservice Soap API.

Requirements
------------

The only dependency is the suds SOAP module, which is available at::
 
    https://fedorahosted.org/suds/
    
You may also use easy_install or pip to install from PyPi::

    pip install suds

Installation
------------

As root/admin on your machine::

    python setup.py install
  
Documentation
-------------

For documentation, see the project webpage at::

    http://code.google.com/p/python-fedex/
    
There are also a lot of useful examples under the examples directory within
this directory.

Support
-------

Head over to https://github.com/gtaylor/python-fedex/issues
and submit an issue if you have any problems or questions.

Legal Mumbo Jumbo
-----------------

Copyright (C) 2012 Gregory Taylor

This software is licensed under the BSD License.

python-fedex is not authored by, endorsed by, or in any way affiliated with
FedEx.